@@ -2,5 +2,8 @@
 //!
 //! A library for simulating Checkmate games.
 
-pub mod land;
 pub mod error;
+pub mod land;
+
+pub use error::*;
+pub use land::*;
